import {AfterViewInit, Component, DoCheck, OnDestroy, OnInit} from '@angular/core';
import {MinutePaper} from '../../dao/minute-paper';
import {StudentInfoService} from 'src/app/services/student-info.service';
import {StudentDataService} from 'src/app/services/student-data.service';
import {StudentViewService} from 'src/app/services/student-view.service';

@Component({
  selector: 'app-student-classview',
  templateUrl: './student-classview.component.html',
  styleUrls: ['./student-classview.component.css']
})
export class StudentClassviewComponent implements OnInit, OnDestroy {

  public openPaperList: MinutePaper[];
  public closedPaperList: MinutePaper[];
  public openClassPapers: MinutePaper[];

  constructor(private studentInfoService: StudentInfoService,
              private studentViewService: StudentViewService,
              private studentDataService: StudentDataService) {
  }

  ngOnInit(): void {
    this.openPaperList = this.studentDataService.openPapers;
    this.closedPaperList = [];
    this.openClassPapers = [];
    this.getOpenClassPapers(this.studentDataService.classCode);
    this.getSubmittedPapers(this.studentDataService.classCode);
  }

  ngOnDestroy(): void {
    this.openPaperList = [];
    this.closedPaperList = [];
    this.openClassPapers = [];
  }

  private getSubmittedPapers(classCode: String) {
    this.studentInfoService.getSubmittedPapers(this.studentDataService.studentId, classCode).subscribe((data: MinutePaper[]) => {
      data.forEach(c => this.closedPaperList.push(c));
    });
  }

  private getOpenClassPapers(classCode: String) {
    this.openPaperList.forEach(e => {
      if (e.classCode === classCode) {
        this.openClassPapers.push(e);
      }
    });
  }
}
