import {Component, OnDestroy, OnInit} from '@angular/core';
import {StudentViewService} from '../services/student-view.service';
import {takeWhile} from 'rxjs/operators';

@Component({
  selector: 'app-student-root',
  templateUrl: './student-root.component.html',
  styleUrls: ['./student-root.component.css']
})
export class StudentRootComponent implements OnInit, OnDestroy {

  private onDashboard: Boolean;
  private onClassView: Boolean;
  private onPaperView: Boolean;
  private isAlive = true;

  constructor(private studentViewService: StudentViewService) {
  }

  ngOnInit(): void {
    this.studentViewService.onDashboard$.subscribe(flag => {
      this.onDashboard = flag;
    }).add(takeWhile(() => this.isAlive));

    this.studentViewService.onClassView$.subscribe(flag => {
      this.onClassView = flag;
    }).add(takeWhile(() => this.isAlive));

    this.studentViewService.onMinutePaper$.subscribe(flag => {
      this.onPaperView = flag;
    }).add(takeWhile(() => this.isAlive));


    this.onDashboard = true;
    this.onClassView = false;
    this.onPaperView = false;

    this.studentViewService.changeDashboard(this.onDashboard);
    this.studentViewService.changeClassView(this.onClassView);
    this.studentViewService.changeMinutePaperView(this.onPaperView);
  }

  ngOnDestroy(): void {
    this.isAlive = false;
  }



}
